@@ -101,15 +101,15 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"core_8h.html#a02b3e6ff573afd1efba25efc8bbb2538",
-"global_8c.html#a457beceeca2fc2e7907289e766a0da13",
-"impl-module_8c.html#a85aaddad8033ae307b8be80052a930f0",
-"keys_8h.html#ad7fe1ca68b65df33c09b8d14cfd708b0",
-"page_node.html",
-"resource_8h.html#ae32b47d6f25f56678385b0c269e8c3e0",
-"structpw__control__events.html#a4e2a4c85f61336fb837a43c931b7c5fa",
-"structpw__node__info.html#ae3b1789c08bcae95888e042790c95b75",
-"unionpw__map__item.html#a51685fc6de470af5d8a477bc98de5bb2"
+"core_8c.html#ae96b51308a9efc1953690b51e69d1353",
+"global_8c.html#a26b8745d75bdc135ac052c3559a65121",
+"impl-link_8h.html#a74d1d9f945a77d49ae6a615f6440b8a8",
+"keys_8h.html#ac760a7d13f161fcc86e964ad23399180",
+"page_context_api.html",
+"resource_8h.html#a400f8bdb7b5779db732e3f224b87e07e",
+"structpw__client__methods.html#a17155250b4b575de0530a8d01447148a",
+"structpw__module__methods.html#ace8dfde4c073903664ba703b575f6e01",
+"thread-loop_8h.html#a58bf781b6f987e80d4a7a6796551dfb1"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
