@@ -1,72 +1,88 @@
 var NAVTREEINDEX6 =
 {
-"resource_8h.html#ae32b47d6f25f56678385b0c269e8c3e0":[11,0,62,21],
-"resource_8h.html#af3044f96f645e97035b87d3b37d3e017":[11,0,62,24],
-"resource_8h.html#af8fe4859dd6826d5eb6c7e28f5519215":[11,0,62,13],
-"resource_8h_source.html":[11,0,62],
-"stream_8c.html":[11,0,63],
-"stream_8c.html#a0aa398ef7b09697a0e48719b27112614":[11,0,63,28],
-"stream_8c.html#a0d2ad73d654de2bc11afe6847474afcb":[11,0,63,35],
-"stream_8c.html#a1676b48e222d9bcf50fd21374ea121c2":[11,0,63,7],
-"stream_8c.html#a1f024c54b2e507824ea0f5441f5b2af4":[11,0,63,33],
-"stream_8c.html#a1ffbabb0a49127dc56c22e466c2903e7":[11,0,63,24],
-"stream_8c.html#a25f4ab4c169e3fef470936e39ba6126f":[11,0,63,6],
-"stream_8c.html#a272af3c2d61d7fb25dc2ab076dc044de":[11,0,63,17],
-"stream_8c.html#a2ab8d1619a5739153a3bff01e6c6788e":[11,0,63,25],
-"stream_8c.html#a40ad70cc6e2125af9340a4bc26a83764":[11,0,63,11],
-"stream_8c.html#a41326ea19a5ae0815a63f0db0a114dfc":[11,0,63,9],
-"stream_8c.html#a430884fd1ac91c74cb5574400a619216":[11,0,63,18],
-"stream_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,63,12],
-"stream_8c.html#a4ce79c03126c9b7166c33cab212283ce":[11,0,63,21],
-"stream_8c.html#a54dfe4670ac6de650a3926b68cadbdb8":[11,0,63,27],
-"stream_8c.html#a65b66a8987387a5894d8414e9573a880":[11,0,63,22],
-"stream_8c.html#a664d10ae36c157ecca989fe0c562017b":[11,0,63,23],
-"stream_8c.html#a7781bc9613ec655352585fb1bac2595d":[11,0,63,10],
-"stream_8c.html#a7d77dd629b7e3a8c6d28cccb93df21e4":[11,0,63,29],
-"stream_8c.html#a89bba79201856c41ea53bd01e65f6438":[11,0,63,8],
-"stream_8c.html#a93f84e7cab1f289398e277aec50a63b8":[11,0,63,16],
-"stream_8c.html#ab41e1c2fa4274c6916e51655e481dd6e":[11,0,63,34],
-"stream_8c.html#ac1d281db6111363227781192d2eb56c7":[11,0,63,32],
-"stream_8c.html#ac9d87c5da34f1357637309ffdd1185cb":[11,0,63,20],
-"stream_8c.html#ad05e907fadaaa1cd21062cd0bb8701a1":[11,0,63,30],
-"stream_8c.html#ad5e65901bc4e01fe66908de6eb983b74":[11,0,63,19],
-"stream_8c.html#ae19fa7dc034a052b0ee1f582e8a949c0":[11,0,63,13],
-"stream_8c.html#ae8a3753316267cd885e875ae7fbd3c91":[11,0,63,26],
-"stream_8c.html#aebbd77924da3cf1c98f8552178f42da6":[11,0,63,15],
-"stream_8c.html#af86bc65adf0e4c18f8ea3c09f5e62d9d":[11,0,63,31],
-"stream_8c.html#afeafcb95f3bc48b81410bf7848473a8f":[11,0,63,14],
-"stream_8h.html":[11,0,64],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106":[11,0,64,5],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b":[11,0,64,5,2],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125":[11,0,64,5,3],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c":[11,0,64,5,4],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a79f1bdb249e79c7e71cf46759936768f":[11,0,64,5,7],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a87c6bfacd40d4f797505fbc22bd2b9da":[11,0,64,5,6],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab111b3fc3e1d3c1c439a65dc85a3ce20":[11,0,64,5,8],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab648fa0c0c7adf6aa3139eddc3a9cd7c":[11,0,64,5,1],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab95a612ea82e3d928b5d2971bcd96465":[11,0,64,5,9],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ad569b3a7085e21df1236651fd3388a22":[11,0,64,5,5],
-"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106aefcc7a31a05fa55c8cff7e686dd484ca":[11,0,64,5,0],
-"stream_8h.html#a065b067d55def0d2c2cedf814a5c55d0":[11,0,64,18],
-"stream_8h.html#a087a686c66c04e54742cc94c7a5e4e68":[11,0,64,13],
-"stream_8h.html#a2d5e07833039ac7a202caaf297556f52":[11,0,64,16],
-"stream_8h.html#a55c1224289e488e27f8d3b6e58abcd08":[11,0,64,17],
-"stream_8h.html#a5ef987fd1903baa7eba9b10a8cbf5e97":[11,0,64,9],
-"stream_8h.html#a751f41a0a5ce1ece31ec126b3cab4fd4":[11,0,64,11],
-"stream_8h.html#a7a8eafa174549733293f11ec2c646827":[11,0,64,14],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82":[11,0,64,6],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a0537b5f9f722fb2faf7822cd09370825":[11,0,64,6,3],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a775f5777259aa54f7ad6d4c7cfa1779f":[11,0,64,6,2],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae02f4af09cb65c931e95e1aa3bdd5f3":[11,0,64,6,1],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae3c1d061da27957fd3a9389b29ff89e":[11,0,64,6,0],
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82af3c3b39039810d40a7c9e1ae3c6c905d":[11,0,64,6,4],
-"stream_8h.html#ab2ef0e28a1e91816f8015ef9814d18f7":[11,0,64,8],
-"stream_8h.html#abe1c593f34080ea9c8c6231abe4e7386":[11,0,64,15],
-"stream_8h.html#adfa74620109228a9cfce24b628aa130f":[11,0,64,7],
-"stream_8h.html#aeb58b45b3e0d8fa804e9165d32159aa2":[11,0,64,10],
-"stream_8h.html#af21c1b002f78067d2eca97c455970822":[11,0,64,4],
-"stream_8h.html#afc74d20ae2305d82aba860fde41b9e31":[11,0,64,12],
-"stream_8h_source.html":[11,0,64],
+"resource_8h.html#a400f8bdb7b5779db732e3f224b87e07e":[11,0,63,3],
+"resource_8h.html#a6000827e0dc8637b0538f75800c0f581":[11,0,63,20],
+"resource_8h.html#a6006f7393419cb5c874398f2954ac1b4":[11,0,63,11],
+"resource_8h.html#a61e286d92a2f528ebe48cb1436ac4eba":[11,0,63,1],
+"resource_8h.html#a6ae5c51e7cab79f755e36c8746973da3":[11,0,63,18],
+"resource_8h.html#a6c7d1b4c88e189e426d762c095e5088e":[11,0,63,10],
+"resource_8h.html#a961e8d61d007ece23ae04afd08e320dc":[11,0,63,15],
+"resource_8h.html#a98bbacb715f5469dcc14a071d14b3883":[11,0,63,8],
+"resource_8h.html#a9edff924e88ea8ae7d0b74065ad7415a":[11,0,63,22],
+"resource_8h.html#aa2d8c1bd7008acbd8fe30e47e6c08d3f":[11,0,63,6],
+"resource_8h.html#aab37d37e596381fec6da22531f78d7bb":[11,0,63,14],
+"resource_8h.html#aadff480a3e38ec195e07567c1e46ab54":[11,0,63,4],
+"resource_8h.html#ab9e159d75b7efe39bd53b64055244092":[11,0,63,7],
+"resource_8h.html#ac7d13ba52bc1796d4baca39ddc4a6f0c":[11,0,63,17],
+"resource_8h.html#aca22b4d01cbb654308199df25efba373":[11,0,63,9],
+"resource_8h.html#ae022953f35be3767c44de0c43fa572e2":[11,0,63,19],
+"resource_8h.html#ae32b47d6f25f56678385b0c269e8c3e0":[11,0,63,21],
+"resource_8h.html#af3044f96f645e97035b87d3b37d3e017":[11,0,63,24],
+"resource_8h.html#af8fe4859dd6826d5eb6c7e28f5519215":[11,0,63,13],
+"resource_8h_source.html":[11,0,63],
+"stream_8c.html":[11,0,64],
+"stream_8c.html#a0aa398ef7b09697a0e48719b27112614":[11,0,64,28],
+"stream_8c.html#a0d2ad73d654de2bc11afe6847474afcb":[11,0,64,35],
+"stream_8c.html#a1676b48e222d9bcf50fd21374ea121c2":[11,0,64,7],
+"stream_8c.html#a1f024c54b2e507824ea0f5441f5b2af4":[11,0,64,33],
+"stream_8c.html#a1ffbabb0a49127dc56c22e466c2903e7":[11,0,64,24],
+"stream_8c.html#a25f4ab4c169e3fef470936e39ba6126f":[11,0,64,6],
+"stream_8c.html#a272af3c2d61d7fb25dc2ab076dc044de":[11,0,64,17],
+"stream_8c.html#a2ab8d1619a5739153a3bff01e6c6788e":[11,0,64,25],
+"stream_8c.html#a40ad70cc6e2125af9340a4bc26a83764":[11,0,64,11],
+"stream_8c.html#a41326ea19a5ae0815a63f0db0a114dfc":[11,0,64,9],
+"stream_8c.html#a430884fd1ac91c74cb5574400a619216":[11,0,64,18],
+"stream_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,64,12],
+"stream_8c.html#a4ce79c03126c9b7166c33cab212283ce":[11,0,64,21],
+"stream_8c.html#a54dfe4670ac6de650a3926b68cadbdb8":[11,0,64,27],
+"stream_8c.html#a65b66a8987387a5894d8414e9573a880":[11,0,64,22],
+"stream_8c.html#a664d10ae36c157ecca989fe0c562017b":[11,0,64,23],
+"stream_8c.html#a7781bc9613ec655352585fb1bac2595d":[11,0,64,10],
+"stream_8c.html#a7d77dd629b7e3a8c6d28cccb93df21e4":[11,0,64,29],
+"stream_8c.html#a89bba79201856c41ea53bd01e65f6438":[11,0,64,8],
+"stream_8c.html#a93f84e7cab1f289398e277aec50a63b8":[11,0,64,16],
+"stream_8c.html#ab41e1c2fa4274c6916e51655e481dd6e":[11,0,64,34],
+"stream_8c.html#ac1d281db6111363227781192d2eb56c7":[11,0,64,32],
+"stream_8c.html#ac9d87c5da34f1357637309ffdd1185cb":[11,0,64,20],
+"stream_8c.html#ad05e907fadaaa1cd21062cd0bb8701a1":[11,0,64,30],
+"stream_8c.html#ad5e65901bc4e01fe66908de6eb983b74":[11,0,64,19],
+"stream_8c.html#ae19fa7dc034a052b0ee1f582e8a949c0":[11,0,64,13],
+"stream_8c.html#ae8a3753316267cd885e875ae7fbd3c91":[11,0,64,26],
+"stream_8c.html#aebbd77924da3cf1c98f8552178f42da6":[11,0,64,15],
+"stream_8c.html#af86bc65adf0e4c18f8ea3c09f5e62d9d":[11,0,64,31],
+"stream_8c.html#afeafcb95f3bc48b81410bf7848473a8f":[11,0,64,14],
+"stream_8h.html":[11,0,65],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106":[11,0,65,5],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b":[11,0,65,5,2],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125":[11,0,65,5,3],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c":[11,0,65,5,4],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a79f1bdb249e79c7e71cf46759936768f":[11,0,65,5,7],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a87c6bfacd40d4f797505fbc22bd2b9da":[11,0,65,5,6],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab111b3fc3e1d3c1c439a65dc85a3ce20":[11,0,65,5,8],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab648fa0c0c7adf6aa3139eddc3a9cd7c":[11,0,65,5,1],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab95a612ea82e3d928b5d2971bcd96465":[11,0,65,5,9],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ad569b3a7085e21df1236651fd3388a22":[11,0,65,5,5],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106aefcc7a31a05fa55c8cff7e686dd484ca":[11,0,65,5,0],
+"stream_8h.html#a065b067d55def0d2c2cedf814a5c55d0":[11,0,65,18],
+"stream_8h.html#a087a686c66c04e54742cc94c7a5e4e68":[11,0,65,13],
+"stream_8h.html#a2d5e07833039ac7a202caaf297556f52":[11,0,65,16],
+"stream_8h.html#a55c1224289e488e27f8d3b6e58abcd08":[11,0,65,17],
+"stream_8h.html#a5ef987fd1903baa7eba9b10a8cbf5e97":[11,0,65,9],
+"stream_8h.html#a751f41a0a5ce1ece31ec126b3cab4fd4":[11,0,65,11],
+"stream_8h.html#a7a8eafa174549733293f11ec2c646827":[11,0,65,14],
+"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82":[11,0,65,6],
+"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a0537b5f9f722fb2faf7822cd09370825":[11,0,65,6,3],
+"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82a775f5777259aa54f7ad6d4c7cfa1779f":[11,0,65,6,2],
+"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae02f4af09cb65c931e95e1aa3bdd5f3":[11,0,65,6,1],
+"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82aae3c1d061da27957fd3a9389b29ff89e":[11,0,65,6,0],
+"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82af3c3b39039810d40a7c9e1ae3c6c905d":[11,0,65,6,4],
+"stream_8h.html#ab2ef0e28a1e91816f8015ef9814d18f7":[11,0,65,8],
+"stream_8h.html#abe1c593f34080ea9c8c6231abe4e7386":[11,0,65,15],
+"stream_8h.html#adfa74620109228a9cfce24b628aa130f":[11,0,65,7],
+"stream_8h.html#aeb58b45b3e0d8fa804e9165d32159aa2":[11,0,65,10],
+"stream_8h.html#af21c1b002f78067d2eca97c455970822":[11,0,65,4],
+"stream_8h.html#afc74d20ae2305d82aba860fde41b9e31":[11,0,65,12],
+"stream_8h_source.html":[11,0,65],
 "structbuffer.html":[10,0,0],
 "structbuffer.html#a236b5ff428b406c814f419f6b70d25ad":[10,0,0,1],
 "structbuffer.html#a587d795f5390416feb6690bc432bf32b":[10,0,0,0],
@@ -101,7 +117,6 @@ var NAVTREEINDEX6 =
 "structfilter.html#a3d3bbf50569618ec2aaaf732be2b939a":[10,0,4,12],
 "structfilter.html#a411f8b027a2391acb338416baee33d71":[10,0,4,6],
 "structfilter.html#a42bfb93f6d5383083c0f5288a43836a4":[10,0,4,10],
-"structfilter.html#a447c7842001ed3fa927244d593ef1d4f":[10,0,4,15],
 "structfilter.html#a576795bfa992c35fddb427543ad5bd59":[10,0,4,5],
 "structfilter.html#a76a94f8c10bd533f2cd367ae43bd87bb":[10,0,4,14],
 "structfilter.html#a78a505bffa0426e75fd31047717d1352":[10,0,4,13],
@@ -111,6 +126,7 @@ var NAVTREEINDEX6 =
 "structfilter.html#ab8c65999c3601116155e31cd7d47e232":[10,0,4,17],
 "structfilter.html#ac2f65174639e5113b0a4a597c1d67bb4":[10,0,4,21],
 "structfilter.html#ac387f99d6533daf6511189240eb0846c":[10,0,4,23],
+"structfilter.html#ac9e1f7af27b4a46d52c06a31dbdea3da":[10,0,4,15],
 "structfilter.html#acd59c2cc491aeaa70daaa087e49a6596":[10,0,4,0],
 "structfilter.html#aea66d542b1b385ea8bccd0c2e54d5a68":[10,0,4,9],
 "structfilter.html#aebd1411b987e755fede0a644fcc65350":[10,0,4,1],
@@ -233,21 +249,5 @@ var NAVTREEINDEX6 =
 "structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21":[10,0,21,1],
 "structpw__client__info.html#a8646eff777b55d33b2d9adc3fd2b9cbe":[10,0,21,2],
 "structpw__client__info.html#a9123521af948ea7b720d1ebb0f39c66b":[10,0,21,0],
-"structpw__client__methods.html":[10,0,22],
-"structpw__client__methods.html#a17155250b4b575de0530a8d01447148a":[10,0,22,4],
-"structpw__client__methods.html#a2804d8a526c068a486a4e261821c9a07":[10,0,22,3],
-"structpw__client__methods.html#a298f33a5d81477d06b08f52d233b740a":[10,0,22,1],
-"structpw__client__methods.html#a7af9e64e81ebc0b3a7d726ff98e0dd84":[10,0,22,2],
-"structpw__client__methods.html#a898d61fc799b5c09421365854020b357":[10,0,22,5],
-"structpw__client__methods.html#ad5cf20929a275ce91d7fdbbb80e70be3":[10,0,22,0],
-"structpw__context__events.html":[10,0,24],
-"structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d":[10,0,24,3],
-"structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e":[10,0,24,1],
-"structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0":[10,0,24,4],
-"structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87":[10,0,24,2],
-"structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c":[10,0,24,5],
-"structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c":[10,0,24,0],
-"structpw__control__events.html":[10,0,26],
-"structpw__control__events.html#a2cda9616fd4aa65d7cc2f8dc6efe69dc":[10,0,26,3],
-"structpw__control__events.html#a4d456606837f25ad3e55471ae23c6bdc":[10,0,26,4]
+"structpw__client__methods.html":[10,0,22]
 };
